pub struct ExitFlag { /* private fields */ }Expand description
A cloneable and distributable flag that can be cheaply queried to see if the game has exited.
The idea is to clone this into in every thread you spawn so that they can gracefully exit when the game does.
Implementations