LfQueueExt

Trait LfQueueExt 

pub trait LfQueueExt: SealedQueue {
    // Required method
    fn write_buffer_padded(
        &self,
        buffer: &Buffer,
        offset: BufferAddress,
        data: Vec<u8>,
    );
}
Extensions to wgpu::Queue.

Required Methods

fn write_buffer_padded( &self, buffer: &Buffer, offset: BufferAddress, data: Vec<u8>, )

Writes the given data to the given buffer using wgpu::Queue::write_buffer, but pads the data to the nearest multiple of the alignment required for buffer writing.

Panics

Panics if the padded data would overrun the given buffer.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl LfQueueExt for Queue

Source

fn write_buffer_padded( &self, buffer: &Buffer, offset: BufferAddress, data: Vec<u8>, )

Implementors